<p align="center">
  tinyweather
</p>

---------------------------

Software for a home weather station.

Tinyweather's main use case is to gather data from climate sensors in an easy to understand format that the user can then play with and analyze.

We will have libraries for rain gauges and BME280/680s.

Tinyweather is maintained by the author of this document.

### Installation

```bash
pip install tinyweather
```

### Contribution

We are happy to have users contribute, however, in the early stages, the author will take a largely dictatorial approach to the software design.

---
## sensors.py

sensors.py is a file that holds classes associated to each sensor attached to the weather station

## main.py

Write your main tinyweather weather station script here.
